@@ -2,15 +2,19 @@
 Provides functions to perform operations on ℝ³ Vectors centered at the
 Origin (0, 0, 0)"""
 
-from math import acos, cos, degrees, exp, hypot, isclose, radians, sin
+
+from typing import Sequence, Iterable, TypeVar
 from types import GeneratorType
+from math import acos, cos, degrees, exp, hypot, isclose, radians, sin
 import matplotlib.pyplot as plt
 from random import uniform
 
-__name__ = "__main__"
+
+__name__: str = "__main__"
+T = TypeVar("T", dict, list, tuple)
 
 
-class Vector():
+class Vector:
     """Vector(x, y, z) = (x)î + (y)ĵ + (z)k̂
     represents a Vector centred at the Origin in 3D space
 
@@ -24,7 +28,7 @@ class Vector():
     Overriding these may result in unusual behaviour"""
 
 
-    def __init__(self, x, y, z, /):
+    def __init__(self, x: float, y: float, z: float, /) -> None:
         """initializes Vector instance
         x, y, z are Real Numbers which represent co-ordinates of the required
         position Vector
@@ -38,7 +42,7 @@ class Vector():
         vec = [x, y, z]
 
         for i in range(3):
-            if not isinstance(vec[i], (int, float)):
+            if not isinstance(vec[i], int|float):
                 raise TypeError(" ".join((
                     "invalid component type for 'Vector':",
                     "must be 'int' / 'float'"
@@ -66,7 +70,7 @@ class Vector():
         }
 
 
-    def __str__(self, /):
+    def __str__(self, /) -> str:
         """defines the str() method for Vector"""
 
         vec = list(Vector.components(self))
@@ -79,47 +83,47 @@ class Vector():
         return f"{sign[0]}{vec[0]}î {sign[1]}{vec[1]}ĵ {sign[2]}{vec[2]}k̂"
 
 
-    def __repr__(self, /):
+    def __repr__(self, /) -> str:
         """defines the repr() method for Vector"""
 
         vec = Vector.components(self)
         return f"Vector({vec[0]}, {vec[1]}, {vec[2]})"
 
 
-    def __bool__(self, /):
+    def __bool__(self, /) -> bool:
         """defines the truth value of a Vector
         bool(Vector.null) == False"""
 
         return not isclose(Vector.mod(self), 0, abs_tol=1e-09)
 
 
-    def __hash__(self, /):
+    def __hash__(self, /) -> int:
         """defines the hash value of a Vector"""
 
         Vector.ExceptionVector(self)
         return hash(repr(self))
 
 
-    def __len__(self, /):
+    def __len__(self, /) -> int:
         """defines the len() method for Vector
         returns the number of dimensions spanned by the Vector"""
 
         return 3 - Vector.components(self).count(0)
 
 
-    def __iter__(self, /):
+    def __iter__(self, /) -> Iterable:
         """implements iter(self)
         iterating over a Vector returns its component - vectors"""
 
         return iter(Vector.componentvectors(self))
 
 
-    def __getitem__(self, axis):
+    def __getitem__(self, axis: str) -> 'Vector':
         """defines indexing property for Vector
         indices defined here:
-          'x' == 'i' = X-component
-          'y' == 'j' = Y-component
-          'z' == 'k' = Z-component"""
+          'x' = 'i' = X-component
+          'y' = 'j' = Y-component
+          'z' = 'k' = Z-component"""
 
         Vector.ExceptionVector(self)
 
@@ -138,7 +142,7 @@ class Vector():
             return {"i": self.x, "j": self.y, "k": self.z}[axis]
 
 
-    def __delattr__(self, name):
+    def __delattr__(self, name: str) -> None:
         """prevents deletion of Vector attrs"""
 
         if not hasattr(self, name):
@@ -147,7 +151,7 @@ class Vector():
             raise AttributeError(f"cannot delete 'Vector' attribute {name !r}")
 
 
-    def __contains__(self, item, /):
+    def __contains__(self, item: 'Vector', /) -> bool:
         """defines membership property for Vector
         returns True if item is a component-vector of self, False otherwise"""
 
@@ -161,7 +165,7 @@ class Vector():
         return item in self.componentvectors()
 
 
-    def __round__(self, digits=0):
+    def __round__(self, digits: int|None = 0) -> 'Vector':
         """defines the round() method for Vector
         round each component of the point to given number of digits"""
 
@@ -169,21 +173,21 @@ class Vector():
         return Vector.FromSequence(result)
 
 
-    def __neg__(self, /):
+    def __neg__(self, /) -> 'Vector':
         """defines the negative of a Vector using unary '-' operator
         -Vector(x, y, z) == Vector(-x, -y, -z)"""
 
         return Vector.scale(self, -1)
 
 
-    def __abs__(self, /):
+    def __abs__(self, /) -> float:
         """defines the abs() method for Vector
         returns the magnitude of the Vector"""
 
         return Vector.mod(self)
 
 
-    def __eq__(self, other, /):
+    def __eq__(self, other: 'Vector', /) -> bool:
         """defines the equality of Vector Objects using '==' operator"""
 
         if type(self) is not type(other):
@@ -192,21 +196,21 @@ class Vector():
             return Vector.components(self) == Vector.components(other)
 
 
-    def __lt__(self, other, /):
+    def __lt__(self, other: 'Vector', /) -> bool:
         """compares magnitudes of Vector Objects using '<' operator
         returns True if magnitude of self is less than magnitude of other"""
 
         return Vector.mod(self) < Vector.mod(other)
 
 
-    def __gt__(self, other, /):
+    def __gt__(self, other: 'Vector', /) -> bool:
         """compares magnitudes of Vector Objects using '>' operator
         returns True if magnitude of self is greater than magnitude of other"""
 
         return Vector.mod(self) > Vector.mod(other)
 
 
-    def __add__(self, other, /):
+    def __add__(self, other: 'Vector', /) -> 'Vector':
         """add Vector Objects using '+' operator
         returns the result for (self + other)"""
 
@@ -214,7 +218,7 @@ class Vector():
         return Vector.FromSequence(v1[i] + v2[i] for i in range(3))
 
 
-    def __sub__(self, other, /):
+    def __sub__(self, other: 'Vector', /) -> 'Vector':
         """subtract Vector Objects using '-' operator
         returns the result for (self - other)"""
 
@@ -222,7 +226,7 @@ class Vector():
         return self + (-other)
 
 
-    def __mul__(self, k, /):
+    def __mul__(self, k: float, /) -> 'Vector':
         """scale the components of the Vector by k using '*' operator
         equivalent to scale(Vector(x, y, z), k)"""
 
@@ -232,7 +236,7 @@ class Vector():
 
 
     @classmethod
-    def ExceptionVector(cls, *vectors):
+    def ExceptionVector(cls, *vectors: 'Vector') -> None:
         """raise Exception when objects passed to functions are not Vectors
         or when attrs of Vector Object are altered"""
 
@@ -248,7 +252,7 @@ class Vector():
 
 
     @classmethod
-    def ExceptionNull(cls, *vectors):
+    def ExceptionNull(cls, *vectors: 'Vector') -> None:
         """raise Exception when Vector.null is passed to functions in which
         Vector.null is unsuported as an argument"""
 
@@ -258,7 +262,10 @@ class Vector():
 
 
     @classmethod
-    def FromAngles(cls, alpha, beta, gamma, /, *, mod=1):
+    def FromAngles(
+            cls, alpha: float, beta: float, gamma: float, /, *,
+            mod: float|None = 1.0
+        ) -> 'Vector':
         """creates a Vector along the given angles with given magnitude
         (angles are in degrees taken counter-clockwise)
         may return pre-defined Vector instances if required
@@ -266,12 +273,12 @@ class Vector():
         direction cosines: cos²𝜶 + cos²𝜷 + cos²𝜸 == 1"""
 
         for angle in alpha, beta, gamma:
-            if not isinstance(angle, (int, float)):
+            if not isinstance(angle, int|float):
                 raise TypeError(" ".join((
                     "'FromAngles' expects all positional",
                     "arguments as 'int' / 'float'"
                 )))
-        if not isinstance(mod, (int, float)):
+        if not isinstance(mod, int|float):
             raise TypeError(
                 "invalid operand type for 'mod': must be 'int' / 'float'"
             )
@@ -293,7 +300,9 @@ class Vector():
 
 
     @classmethod
-    def FromSequence(cls, sequence, /):
+    def FromSequence(cls,
+            sequence: dict[str, float]|list[float]|tuple[float]|GeneratorType,
+        /) -> 'Vector':
         """creates a Vector from the given sequence / generator
         the sequence must have len(sequence) == 3 / the generator must yield 3
         int / float numbers
@@ -303,7 +312,7 @@ class Vector():
             • {'x': x, 'y': y, 'z': z}
             • {'i': x, 'j': y, 'k': z}"""
 
-        if not isinstance(sequence, (dict, list, tuple, GeneratorType)):
+        if not isinstance(sequence, dict|list|tuple|GeneratorType):
             raise TypeError(" ".join((
                 "invalid sequence type for 'Vector':",
                 "see help(FromSequence) for help on valid sequences"
@@ -341,7 +350,7 @@ class Vector():
 
 
     @staticmethod
-    def zeroresultant(*vectors):
+    def zeroresultant(*vectors: 'Vector') -> bool:
         """returns True if the resultant of the given Vectors is Vector.null,
         False otherwise
         all Vectors add upto Vector.null ⇒ they form a closed polygon"""
@@ -350,7 +359,27 @@ class Vector():
 
 
     @staticmethod
-    def plot_vectors(*vectors, show_legend=True):
+    def random(*, mod: float|None = 1.0) -> 'Vector':
+        """returns a Vector with the given magnitude in a random direction
+        passing argument mod as 0 returns Vector.null"""
+
+        if not isinstance(mod, int|float):
+            raise TypeError(
+                "invalid operand type for 'mod': must be 'int' / 'float'"
+            )
+        if mod < 0:
+            raise ValueError(
+                "invalid operand for 'mod': must be positive 'int' / 'float'"
+            )
+        if not mod:
+            return Vector.null
+
+        result = uniform(-1, 1), uniform(-1, 1), uniform(-1, 1)
+        return Vector.FromSequence(result).unit().scale(mod)
+
+
+    @staticmethod
+    def plot_vectors(*vectors: 'Vector', show_legend: bool|None =True) -> None:
         """plots all given Vectors in the same plot
         show_legend is a boolean which displays legend on the plot if True"""
 
@@ -391,13 +420,13 @@ class Vector():
         plt.show()
 
 
-    def plot(self, /):
+    def plot(self, /) -> None:
         """plots the Vector on a 3D plot and displays it"""
 
         Vector.plot_vectors(self)
 
 
-    def mod(self, /):
+    def mod(self, /) -> float:
         """returns the magnitude (absolute value) of the Vector
         mod(Vector(x, y, z)) == √(|x|² + |y|² + |z|²)"""
 
@@ -405,7 +434,7 @@ class Vector():
         return self.magnitude
 
 
-    def components(self, /):
+    def components(self, /) -> tuple[float]:
         """returns a tuple containing rectangular components of the Vector
         components(Vector(x, y, z)) == (x, y, z)"""
 
@@ -413,7 +442,7 @@ class Vector():
         return self.tuple
 
 
-    def tosequence(self, sequence, *, keys=None):
+    def tosequence(self, sequence: T, *, keys: Sequence[str]|None = None) -> T:
         """returns the given Vector as a dict, list or tuple of components
         if the required sequence type is 'dict', keys must be given as
         a list, set, str or tuple
@@ -428,7 +457,7 @@ class Vector():
         if sequence not in {dict, list, tuple}:
             raise TypeError(" ".join((
                 "invalid operand type for 'sequence':",
-                "must be 'type' ('dict', 'list' or 'tuple'}"
+                "must be 'type' ('dict', 'list' or 'tuple')"
             )))
 
         if sequence is dict:
@@ -436,7 +465,7 @@ class Vector():
                 raise TypeError(
                     "argument 'keys' must be given for sequence type 'dict'"
                 )
-            if not isinstance(keys, (list, set, str, tuple)):
+            if not isinstance(keys, list|set|str|tuple):
                 raise TypeError(" ".join((
                     "invalid operand type for 'keys':",
                     "must be 'list', 'set', 'tuple' or 'str'"
@@ -454,7 +483,7 @@ class Vector():
             return sequence(vec)
 
 
-    def componentvectors(self, /):
+    def componentvectors(self, /) -> tuple['Vector']:
         """returns a tuple containing the component Vectors of the given Vector
         componentvectors(Vector(x, y, z)) == (
             Vector(x, 0, 0), Vector(0, y, 0), Vector(0, 0, z)
@@ -466,7 +495,7 @@ class Vector():
         return tuple(vec)
 
 
-    def resolve(self, /):
+    def resolve(self, /) -> dict['Vector', float]:
         """returns a dict of rectangularly resolved components of the Vector
         resolve(Vector(x, y, z)) == {î: x, ĵ: y, k̂: z}"""
 
@@ -474,15 +503,15 @@ class Vector():
         return {Vector.i: x, Vector.j: y, Vector.k: z}
 
 
-    def octant(self, /):
+    def octant(self, /) -> int:
         """returns the octant in which the given Vector lies as 'int'
         returns NotImplemented if any component of the Point is zero
         i.e., Vector(x, y, z), where x, y, z ≠ 0
         octants are numbered as per convention:
-            1. (+, +, +)      5.  (+, +, -)
-            2. (-, +, +)      6.  (-, +, -)
-            3. (-, -, +)      7.  (-, -, -)
-            4. (+, -, +)      8.  (+, -, -)"""
+            1. (+, +, +)      5. (+, +, -)
+            2. (-, +, +)      6. (-, +, -)
+            3. (-, -, +)      7. (-, -, -)
+            4. (+, -, +)      8. (+, -, -)"""
 
         Vector.ExceptionVector(self)
 
@@ -509,7 +538,7 @@ class Vector():
         return 8
 
 
-    def axis(self, /):
+    def axis(self, /) -> int:
         """returns the axis on which the given Vector lies as 'int'
         returns NotImplemented if two components of the Point are not zero
         i.e., Vector(x, 0, 0), Vector(0, y, 0), Vector(0, 0, z),
@@ -529,7 +558,7 @@ class Vector():
         return 3
 
 
-    def directioncos(self, /):
+    def directioncos(self, /) -> tuple[float]:
         """returns a tuple containing direction cosines of the Vector
         directioncos(FromAngles(𝜶, 𝜷, 𝜸, mod=n)) == (cos𝜶, cos𝜷, cos𝜸)
         see help(FromAngles) for help on angles & direction cosines"""
@@ -537,7 +566,7 @@ class Vector():
         return Vector.unit(self).tuple
 
 
-    def axis_angles(self, /):
+    def axis_angles(self, /) -> tuple[float]:
         """returns a tuple of angles (in degrees) that the Vector makes with
         the co-ordinate axes
         axis_angles(FromAngles(𝜶, 𝜷, 𝜸, mod=n)) == (𝜶, 𝜷, 𝜸)
@@ -548,7 +577,7 @@ class Vector():
         )
 
 
-    def polar_repr(self, /):
+    def polar_repr(self, /) -> str:
         """returns a str of representation of the Vector the Polar form
         polar_repr(FromAngles(𝜶, 𝜷, 𝜸, mod=n)) returns a str of the form
         n(cos(𝜶)î + cos(𝜷)ĵ + cos(𝜸)k̂)"""
@@ -557,7 +586,7 @@ class Vector():
         return f"{self.mod()}(cos({alpha})î + cos({beta})ĵ + cos({gamma})k̂"
 
 
-    def dot(self, other, /):
+    def dot(self, other: 'Vector', /) -> float:
         """performs dot product / scalar product on two Vectors and
         returns the result (scalar)
         dot(Vector(a, b, c), Vector(d, e, f)) is equivalent to
@@ -567,7 +596,7 @@ class Vector():
         return sum([v1[i] * v2[i] for i in range(3)])
 
 
-    def cross(self, other, /):
+    def cross(self, other: 'Vector', /) -> 'Vector':
         """performs cross product / vector product on two Vectors and
         returns the result (Vector)
         cross(Vector(a, b, c), Vector(d, e, f)) is equivalent to
@@ -582,23 +611,23 @@ class Vector():
         ])
 
 
-    def scalar_triple(self, value1, value3, /):
+    def scalar_triple(self, v2: 'Vector', v3: 'Vector', /) -> float:
         """returns the result (scalar) of scalar triple product of the Vectors
         taken in order
         scalar_triple(v1, v2, v3) == dot(v1, cross(v2, v3))"""
 
-        return Vector.dot(self, Vector.cross(value1, value3))
+        return Vector.dot(self, Vector.cross(v2, v3))
 
 
-    def vector_triple(self, value1, value3, /):
+    def vector_triple(self, v2: 'Vector', v3: 'Vector', /) -> 'Vector':
         """returns the result (Vector) of vector triple product of the Vectors
         taken in order
         vector_triple(v1, v2, v3) == cross(v1, cross(v2, v3))"""
 
-        return Vector.cross(self, Vector.cross(value1, value3))
+        return Vector.cross(self, Vector.cross(v2, v3))
 
 
-    def scale(self, /, k):
+    def scale(self, /, k: float) -> 'Vector':
         """scales the Vector by scalar k and returns the result
         scale(Vector(x, y, z), 𝝀) == Vector(𝝀x, 𝝀y, 𝝀z)"""
 
@@ -606,14 +635,14 @@ class Vector():
 
         if k == 1:
             return self
-        if not isinstance(k, (int, float)):
+        if not isinstance(k, int|float):
             raise TypeError(
                 "invalid operand type for 'k': must be 'int' / 'float'"
             )
         return Vector.FromSequence(comp * k for comp in self.tuple)
 
 
-    def angle(self, other, /):
+    def angle(self, other: 'Vector', /) -> float:
         """returns the angle (in degrees) between the given Vectors
         for any two Vectors v1 and v2:
             angle(v1, v2) == cos⁻¹(dot(v1, v2) / (mod(v1) * mod(v2)))
@@ -624,7 +653,7 @@ class Vector():
         return round(degrees(acos(round(result, 10))), 10)
 
 
-    def isscaledof(self, other, /):
+    def isscaledof(self, other: 'Vector', /) -> bool:
         """returns True if the given Vectors are scaled versions of each other,
         False otherwise
         Note: using Vector.null as either of the operands raises Exception"""
@@ -632,7 +661,7 @@ class Vector():
         return Vector.isparallel(self, other)
 
 
-    def scalefactor(self, other, /):
+    def scalefactor(self, other: 'Vector', /) -> float:
         """returns the scale factor by which self is scaled to get other if the
         Vectors are scaled versions of each other, else NotImplemented"""
 
@@ -643,7 +672,7 @@ class Vector():
         return NotImplemented
 
 
-    def unit(self, /):
+    def unit(self, /) -> 'Vector':
         """returns the unit Vector along the direction of the given Vector
         for a Vector: v = Vector(x, y, z)
         unit(v) == scale(v, 1/mod(v))
@@ -653,7 +682,7 @@ class Vector():
         return self.scale(1 / self.magnitude)
 
 
-    def inverse(self, /):
+    def inverse(self, /) -> 'Vector':
         """returns the inverse of a Vector
         for a Vector: v = Vector(x, y, z)
         inverse(v) == scale(unit(v), 1/mod(v)) == scale(v, 1/mod(v)²)
@@ -662,13 +691,15 @@ class Vector():
         return Vector.unit(self).scale(1 / self.magnitude)
 
 
-    def section_internal(self, other, /, m, n):
+    def section_internal(
+            self, other: 'Vector', /, m: float, n: float
+        ) -> 'Vector':
         """returns the Vector which sections the line joining self and
-        other in the ratio m : n internally
+        other in the ratio m:n internally
         Note: m and n must be positive Real numbers"""
 
         for num in m, n:
-            if not isinstance(num, (int, float)):
+            if not isinstance(num, int|float):
                 raise TypeError("'m' and 'n' must be positive 'int' / 'float'")
             if num <= 0:
                 raise ValueError("'m' and 'n' must be positive 'int' / 'float'")
@@ -676,9 +707,11 @@ class Vector():
         return (Vector.scale(other, m) + Vector.scale(self, n)).scale(1 / (m+n))
 
 
-    def section_external(self, other, /, m, n):
+    def section_external(
+            self, other: 'Vector', /, m: float, n: float
+        ) -> 'Vector':
         """returns the Vector which sections the line joining self and
-        other in the ratio m : n externally
+        other in the ratio m:n externally
         Note: m and n must be positive Real numbers
         returns NotImplemented if no such Vector exists, i.e. when m = n"""
 
@@ -689,13 +722,13 @@ class Vector():
             return (other.scale(m) - self.scale(n)).scale(1 / (m-n))
 
 
-    def isunit(self, /):
+    def isunit(self, /) -> bool:
         """returns True if the given Vector is a unit Vector, False otherwise"""
 
         return isclose(Vector.mod(self), 1, abs_tol=1e-09)
 
 
-    def isinverse(self, other, /):
+    def isinverse(self, other: 'Vector', /) -> bool:
         """returns True if the given Vectors are inverses of each other,
         False otherwise"""
 
@@ -703,23 +736,23 @@ class Vector():
         return round(self, 10) == round(other.inverse(), 10)
 
 
-    def equalmod(self, other, /):
+    def equalmod(self, other: 'Vector', /) -> bool:
         """returns True if the given Vectors are equal in magnitude,
         False otherwise"""
 
         return Vector.mod(self) == Vector.mod(other)
 
 
-    def iscoplanar(self, value2, value3, /):
+    def iscoplanar(self, v2: 'Vector', v3: 'Vector', /) -> bool:
         """returns True if the given Vectors are co-planar, False otherwise
         Note: using Vector.null as any of the operands returns True"""
 
         return isclose(
-            Vector.scalar_triple(self, value2, value3), 0, abs_tol=1e-09
+            Vector.scalar_triple(self, v2, v3), 0, abs_tol=1e-09
         )
 
 
-    def isparallel(self, other, /):
+    def isparallel(self, other: 'Vector', /) -> bool:
         """returns True if the given Vectors are parallel, False otherwise
         Note: using Vector.null as either of the operands raises Exception"""
 
@@ -727,7 +760,7 @@ class Vector():
         return not self.cross(other)
 
 
-    def isperpendicular(self, other, /):
+    def isperpendicular(self, other: 'Vector', /) -> bool:
         """returns True if the given Vectors are perpendicular, False otherwise
         Note: using Vector.null as either of the operands raises Exception"""
 
@@ -735,26 +768,7 @@ class Vector():
         return isclose(self.dot(other), 0, abs_tol=1e-09)
 
 
-    def random(*, mod=1):
-        """returns a Vector with the given magnitude in a random direction
-        passing argument mod as 0 returns Vector.null"""
-
-        if not isinstance(mod, (int, float)):
-            raise TypeError(
-                "invalid operand type for 'mod': must be 'int' / 'float'"
-            )
-        if mod < 0:
-            raise ValueError(
-                "invalid operand for 'mod': must be positive 'int' / 'float'"
-            )
-        if not mod:
-            return Vector.null
-
-        result = uniform(-1, 1), uniform(-1, 1), uniform(-1, 1)
-        return Vector.FromSequence(result).unit().scale(mod)
-
-
-    def transform(self, /, i, j, k):
+    def transform(self, /, i: 'Vector', j: 'Vector', k: 'Vector') -> 'Vector':
         """returns the Linearly Transformed version of the given Vector when
         new Vectors i, j, k are chosen as the Basis Vectors
         i, j, k = Vector for new Vector.i, Vector.j, Vector.k
@@ -768,7 +782,7 @@ class Vector():
         return i.scale(x) + j.scale(y) + k.scale(z)
 
 
-    def shear2D(self, /):
+    def shear2D(self, /) -> 'Vector':
         """performs 2-dimensional Shear Linear Transformation on the given
         Vector and returns the result
         for a Vector: v = Vector(x, y, z)
@@ -778,7 +792,7 @@ class Vector():
         return Vector.transform(self, i, j, k)
 
 
-    def shear3D(self, /):
+    def shear3D(self, /) -> 'Vector':
         """performs 3-dimensional Shear Linear Transformation on the given
         Vector and returns the result
         for a Vector: v = Vector(x, y, z)
@@ -788,32 +802,32 @@ class Vector():
         return Vector.transform(self, i, j, k)
 
 
-    def isindependent(self, value2, value3, /):
+    def isindependent(self, v2: 'Vector', v3: 'Vector', /) -> bool:
         """returns True if the given Vectors are Linearly Independent,
         False otherwise
         isindependent(v1, v2, v3) == (scalar_triple(v1, v2, v3) != 0)"""
 
-        return not Vector.iscoplanar(self, value1, value2)
+        return not Vector.iscoplanar(self, v2, v3)
 
 
-    def rank(self, value2, value3, /):
+    def rank(self, v2: 'Vector', v3: 'Vector', /) -> int:
         """returns the rank of (dimensions spanned by) three Vectors
         Note: using Vector.null as either of the operands raises Exception"""
 
-        if Vector.isindependent(self, value2, value3):
+        if Vector.isindependent(self, v2, v3):
             return 3
 
         p1 = self.isparallel(value2)
-        p2 = value2.isparallel(value3)
-        p3 = value3.isparallel(self)
+        p2 = v2.isparallel(v3)
+        p3 = v3.isparallel(self)
 
-        if not all({p1, p2, p3}):
+        if not all([p1, p2, p3]):
             return 2
         else:
             return 1
 
 
-    def rotate(self, /, *, yaw, pitch, roll):
+    def rotate(self, /, *, yaw: float, pitch: float, roll: float) -> 'Vector':
         """rotates the Vector by the given yaw, pitch and roll angles using
         the Right-Hand Rule (angles are in degrees taken counter-clockwise)
         formally, this corresponds to an intrinsic rotation whose Tait-Bryan
@@ -822,7 +836,7 @@ class Vector():
         x, y, z = Vector.components(self)
 
         for angle in yaw, pitch, roll:
-            if not isinstance(angle, (int, float)):
+            if not isinstance(angle, int|float):
                 raise TypeError(" ".join((
                     "inalid operand type(s) for 'yaw', 'pitch' or 'roll':",
                     "must be 'int' / 'float'"
@@ -839,9 +853,11 @@ class Vector():
         return round(Vector.FromSequence([X, Y, Z]), 10)
 
 
-    def rotate_vector(self, other, /, *, phi=90):
+    def rotate_vector(
+            self, other: 'Vector', /, *, phi: float|None = 90.0
+        ) -> 'Vector':
         """rotates the Vector self phi degrees about the Vector other using
-        the Right-Hand Rule. phi can be any Real Number.
+        the Right-Hand Rule.
         when phi > 0, the rotation will be counter-clockwise when 'other' points
         towards the observer.
         a Vector rotated about its own axis returns itself
@@ -849,12 +865,13 @@ class Vector():
 
         Vector.ExceptionVector(self, other)
 
-        if not isinstance(phi, (int, float)):
+        if not isinstance(phi, int|float):
             raise TypeError(
                 "invalid operand type 'phi': must be 'int' / 'float'"
             )
         phi = radians(phi)
         other = other.unit()
+
         result1 = other.scale(self.dot(other))
         result2 = other.vector_triple(other, self).scale(-cos(phi))
         result3 = other.cross(self).scale(sin(phi))
@@ -862,16 +879,16 @@ class Vector():
         return round(sum([result1, result2, result3], Vector.null), 10)
 
 
-    def rotate_axis(self, /, axis, *, phi=90):
+    def rotate_axis(self, /, axis: str, *, phi: float|None = 90.0) -> 'Vector':
         """rotates the Vector by phi degrees about positive direction of the
-        given axis using the Right-Hand Rule. phi can be any Real Number.
+        given axis using the Right-Hand Rule.
         when phi > 0, the rotation will be counter-clockwise when the positive
         direction of axis of rotation points towards the observer.
         a Vector rotated about its own axis returns itself
         axes defined here:
-          'x' == 'i' = X-axis
-          'y' == 'j' = Y-axis
-          'z' == 'k' = Z-axis"""
+          'x' = 'i' = X-axis
+          'y' = 'j' = Y-axis
+          'z' = 'k' = Z-axis"""
 
         Vector.ExceptionVector(self)
 
@@ -896,9 +913,9 @@ class Vector():
         return Vector.unit(self).scale(exp(Vector.mod(self)))
 
 
-Vector.i = Vector(1, 0, 0)
-Vector.j = Vector(0, 1, 0)
-Vector.k = Vector(0, 0, 1)
-Vector.null = Vector(0, 0, 0)
+Vector.i: Vector = Vector(1, 0, 0)
+Vector.j: Vector = Vector(0, 1, 0)
+Vector.k: Vector = Vector(0, 0, 1)
+Vector.null: Vector = Vector(0, 0, 0)
 
-__name__ = "pyvectors"
\ No newline at end of file
+__name__: str = "pyvectors"
\ No newline at end of file
